=============
PartitialAjax
=============

.. js:autoclass:: PartitialAjax
    :members:
    :private-members:


.. js:autofunction:: getCookie

.. js:autofunction:: jsconsole

.. js:autofunction:: camelToKebab

.. js:autofunction:: kebabToCamel


.. _partitial-ajax-options:

Options
=======

Available Options:
 * url
 * element
 * onlyChildReplace
 * interval
 * allowedElements
 * textEventCallback
 * restrictRemoteConfiguration
 * configFromElement
 * directLoad


.. _partitial-ajax-events:

Events
=======

Available Events:
 * afterSetup (constructor)
 * onRemoteError
 * onRemoteData
 * onHandeldRemoteData
 * onResponseError